Attestation

Struct Attestation 

pub struct Attestation {
    pub key_id: String,
    pub signature: [u8; 64],
    pub signed_at: DateTime<Utc>,
}
Cryptographic proof that an event originated from the named principal.

Wire shape (ADR 0014 “Signed preimage”). Note: the signature field is the only part of an event payload not included in the canonical preimage (a 64-byte signature cannot sign itself), but key_id and signed_at are included so a captured signature cannot be moved to a different timestamp or rebound to a different key.

Fields

key_id: String

Public-key fingerprint (matches Attestor::key_id).

signature: [u8; 64]

Ed25519 signature over canonical_signing_input.

signed_at: DateTime<Utc>

Wall-clock timestamp the signature was produced at; MUST equal the signed_at field in the preimage that was signed.