pub enum KeyLifecycleState {
Active,
Retired,
Revoked,
}Expand description
Key lifecycle state from ADR 0023.
Variants
Active
Key may sign new material from this effective time.
Retired
Key may not sign new material after this effective time.
Revoked
Key may not sign new material after this effective time.