pub enum ProofState {
FullChainVerified,
Partial,
Broken,
}Expand description
Overall state of a proof closure check.
Variants
FullChainVerified
Every required edge was present and verified.
Partial
Some required edge is missing or unresolved, but no contradiction was observed.
Broken
At least one required edge was observed and found invalid.